package lab7_state.ex2;

import lab7_state.ex2.states.*;

public class User {
    private final String name;
    private UserState currentState;
    private final UserState unregisteredState;
    private final UserState registeredState;
    private final UserState inMeetingState;
    private final UserState waitingToSpeakState;
    private final UserState speakingState;

    public User(String name) {
        this.name = name;
        unregisteredState = new UnregisteredState(this);
        registeredState = new RegisteredState(this);
        inMeetingState = new InMeetingState(this);
        waitingToSpeakState = new WaitingToSpeakState(this);
        speakingState = new SpeakingState(this);
        currentState = unregisteredState;
    }

    public void setCurrentState(UserState currentState) {
        this.currentState = currentState;
    }

    public UserState getUnregisteredState() {
        return unregisteredState;
    }

    public UserState getRegisteredState() {
        return registeredState;
    }

    public UserState getInMeetingState() {
        return inMeetingState;
    }

    public UserState getWaitingToSpeakState() {
        return waitingToSpeakState;
    }

    public UserState getSpeakingState() {
        return speakingState;
    }

    public void connect() {
        currentState.connect();
    }
    public void enter() {
        currentState.enter();
    }
    public void leave() {
        currentState.leave();
    }
    public void ask() {
        currentState.ask();
    }
    public void handOver() {
        currentState.handOver();
    }
    public void over() {
        currentState.over();
    }

    @Override
    public String toString() {
        return "User " + name;
    }
}
